
# THIS FILE IS GENERATED FROM SKNANO SETUP.PY
short_version = '0.2.21'
version = '0.2.21'
full_version = '0.2.21'
git_revision = 'a38dbb3fa70a07f1ec0d7cdc4779798dfa63d356'
release = True

if not release:
    version = full_version
